@@ -14,6 +14,7 @@
  * limitations under the License.
  *
  * SPDX-License-Identifier: Apache-2.0
+ * Copyright (c) OWASP Foundation. All Rights Reserved.
  */
 use std::io::{self, Write};
 
@@ -28,37 +29,3 @@ pub trait ToXml {
     ///   function was invoked.
     fn to_xml<W: Write>(&self, xml: &mut XmlWriter<W>) -> io::Result<()>;
 }
-
-/// Check if `self` contains meaningful data.
-pub trait IsEmpty {
-    /// Check if `self` contains meaningful data.
-    fn is_empty(&self) -> bool;
-}
-
-impl<'a> IsEmpty for &'a str {
-    fn is_empty(&self) -> bool {
-        !self.trim().is_empty()
-    }
-}
-
-impl IsEmpty for String {
-    fn is_empty(&self) -> bool {
-        self.as_str().is_empty()
-    }
-}
-
-impl<T: IsEmpty> IsEmpty for Option<T> {
-    fn is_empty(&self) -> bool {
-        if let Some(v) = self {
-            v.is_empty()
-        } else {
-            true
-        }
-    }
-}
-
-impl<T> IsEmpty for Vec<T> {
-    fn is_empty(&self) -> bool {
-        Vec::<T>::is_empty(self)
-    }
-}
